/*
 * RCache - A collection of simple reference-based cache implementations.
 * Copyright (C) 2007  Rodrigo Ruiz
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the Apache 2.0 license (the "Apache License"), in which case its
 * provisions are applicable instead of those above. If you wish to allow use
 * of your version of this file only* under the terms of the Apache License
 * and not to allow others to use your version of this file under the LGPL,
 * indicate your decision by* deleting the provisions above and replace them
 * with the notice and other provisions required by the Apache License. If
 * you do not delete the provisions above, a recipient may use your version of
 * this file under either the LGPL or the Apache License.
 */
package net.sourceforge.rcache;

/**
 * <p>Reference with an attached key to be used in a cache.</p>
 *
 * <p>Although it cannot be enforced/checked at compilation time, the contract
 * for this interface is that all implementors MUST be subclasses of
 * {@link java.lang.ref.Reference}.</p>
 *
 * @author Rodrigo Ruiz
 * @param <K> the type of keys maintained by this cache
 * @param <V> the type of cached values
 */
public interface KeyedReference<K, V> {

  /**
   * Gets the key for this reference.
   *
   * @return The key
   */
  K getKey();

  /**
   * Gets the referenced value.
   *
   * @return The value
   */
  V get();
}
